package logic

import (
	"context"
	"time"

	"GtDataStore/app/cmd/organization/internal/svc"
	"GtDataStore/app/cmd/organization/pb"

	"github.com/zeromicro/go-zero/core/logx"
)

type ExpireAppSecretLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewExpireAppSecretLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ExpireAppSecretLogic {
	return &ExpireAppSecretLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *ExpireAppSecretLogic) ExpireAppSecret(in *pb.ExpireAppSecretReq) (*pb.ExpireAppSecretResp, error) {
	appInfo, err := l.svcCtx.AppInfo.FindOneByAppName(l.ctx, in.AppName)
	if err != nil {
		return nil, err
	}

	appInfo.ExpireAt = appInfo.ExpireAt.Add(time.Duration(in.Expire) * time.Second)

	err = l.svcCtx.AppInfo.Update(l.ctx, appInfo)
	if err != nil {
		return nil, err
	}

	return &pb.ExpireAppSecretResp{ExpireAt: appInfo.ExpireAt.Format("2006-01-02 15:04:05")}, nil
}
